@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.3.0
+# @version 2.3.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -242,7 +242,7 @@ RANLIB    = """+self.config.ranlib+"""
         shutil.copy('lib/libcblas.a',os.path.join(self.prefix,'lib/libcblas.a'))
 
         # move cblas.h to the include directory
-        shutil.copy('src/cblas.h',os.path.join(self.prefix,'include/cblas.h'))
+        shutil.copy('include/cblas.h',os.path.join(self.prefix,'include/cblas.h'))
 
         # set framework variables to point to the freshly installed BLAS library
         self.config.cblaslib  = '-L'+os.path.join(self.prefix,'lib')+' -lcblas'
