@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.3.0
+# @version 2.3.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -236,7 +236,7 @@ LIBCLAPACK  = """+self.config.lapclib+"""
             print 'Running PLASMA tests on',self.nbcores, 'cores...(takes some time, feel free to grab a coffee!)'
             print '--> testing ...',
             sys.stdout.flush()
-            comm = './plasma_testing.py ' + str(self.nbcores)
+            comm = './plasma_testing.py -c ' + str(self.nbcores)
             (output, error, retz) = runShellCommand(comm, sys.stdout)
             if retz:
                 print '\n\nPLASMA: Testing failed... '
